@@ -1,5 +1,6 @@
 from .browser_control import Control
+from .getters import Getters
 from .input import Input
 from .validation import Validation
 
-__all__ = ["Control", "Input", "Validation"]
+__all__ = ["Control", "Getters", "Input", "Validation"]
