@@ -1,9 +1,10 @@
 from typing import Optional
 
 from robot.api import logger  # type: ignore
+from robot.utils.robottime import timestr_to_secs  # type: ignore
 from robotlibcore import keyword  # type: ignore
 
-from ..generated import playwright_pb2
+from ..generated.playwright_pb2 import Request
 
 
 class Control:
@@ -15,15 +16,16 @@ class Control:
         return self.library.playwright
 
     @keyword
-    def open_browser(self, browser="Chrome", url=None):
-        """Opens a new browser instance to the optional ``url``.
-        The ``browser`` argument specifies which browser to use. The
+    def open_browser(self, url=None, browser="Chromium", headless: bool = True):
+        """Opens a new browser instance.
+        The optional ``url`` argument specifies what to open.
+        The optional ``browser`` argument specifies which browser to use. The
         supported browsers are listed in the table below. The browser names
         are case-insensitive and some browsers have multiple supported names.
-        |    = Browser =    |        = Name(s) =        |
-        | Firefox           | firefox                   |
-        | Google Chrome     | chrome                    |
-        | WebKit            | webkit                    |
+        |   = Browser =   |        = Name(s) =        |
+        | Firefox         | firefox                   |
+        | Chromium        | chromium                  |
+        | WebKit          | webkit                    |
 
         """
         browser_ = browser.lower().strip()
@@ -34,7 +36,9 @@ class Control:
             )
         with self.playwright.grpc_channel() as stub:
             response = stub.OpenBrowser(
-                playwright_pb2.openBrowserRequest(url=url or "", browser=browser_)
+                Request().openBrowser(
+                    url=url or "", browser=browser_, headless=headless
+                )
             )
             logger.info(response.log)
 
@@ -42,22 +46,28 @@ class Control:
     def close_browser(self):
         """Closes the current browser."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.CloseBrowser(playwright_pb2.Empty())
+            response = stub.CloseBrowser(Request.Empty())
             logger.info(response.log)
 
     @keyword
-    def get_url(self):
-        """Returns curent URL."""
+    def go_forward(self):
+        """Navigate to the next page in history."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.GetUrl(playwright_pb2.Empty())
+            response = stub.GoForward(Request.Empty())
+            logger.info(response.log)
+
+    @keyword
+    def go_back(self):
+        """Navigate to the previous page in history."""
+        with self.playwright.grpc_channel() as stub:
+            response = stub.GoBack(Request.Empty())
             logger.info(response.log)
-            return response.body
 
     @keyword
     def go_to(self, url: str):
         """Navigates the current browser tab to the provided ``url``."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.GoTo(playwright_pb2.goToRequest(url=url))
+            response = stub.GoTo(Request().goTo(url=url))
             logger.info(response.log)
 
     @keyword
@@ -69,5 +79,16 @@ class Control:
             path = self.library.get_screenshot_path
         logger.info(f"Taking screenshot into ${path}")
         with self.playwright.grpc_channel() as stub:
-            response = stub.Screenshot(playwright_pb2.screenshotRequest(path=path))
+            response = stub.Screenshot(Request().screenshot(path=path))
+            logger.info(response.log)
+
+    @keyword
+    def set_timeout(self, timeout: str):
+        """ Sets the timeout that is used by most input and getter keywords.
+
+            Technically this is the timeout of current playwright context.
+        """
+        parsed_timeout = float(timestr_to_secs(timeout)) * 1000
+        with self.playwright.grpc_channel() as stub:
+            response = stub.SetTimeout(Request().timeout(timeout=parsed_timeout))
             logger.info(response.log)
